@@ -9,12 +9,13 @@
 //!
 //! This library assumes that the `client_encoding` backend parameter has been
 //! set to `UTF8`. It will most likely not behave properly if that is not the case.
-#![doc(html_root_url="https://sfackler.github.io/rust-postgres-protocol/doc/v0.1.1")]
+#![doc(html_root_url="https://docs.rs/postgres-protocol/0.2.0")]
 #![warn(missing_docs)]
 extern crate byteorder;
 extern crate fallible_iterator;
 extern crate hex;
 extern crate md5;
+extern crate memchr;
 
 use byteorder::{WriteBytesExt, BigEndian};
 use std::io;
